@@ -1,5 +1,5 @@
-from .uiPyQt2 import *
+from uipyqt2 import *
 
 __author__ = "brauser_vekato"
-__version__ = "0.2.1"
+__version__ = "0.2.6"
 __email__ = "vovbon6767@gmail.com"
\ No newline at end of file
